@@ -6,6 +6,7 @@
 #' }{
 #'   t != r.
 #' }
+#' The one-zero loss is 1 - zero-one.
 #'
 #' @templateVar mid zero_one
 #' @template classif_template
@@ -17,5 +18,14 @@ zero_one = function(truth, response, ...) {
   as.integer(truth != response)
 }
 
+#' @rdname zero_one
+#' @export
+one_zero = function(truth, response, ...) {
+  assert_classif(truth, response)
+  as.integer(truth == response)
+}
+
 #' @include measures.R
 add_measure(zero_one, "Zero-One Classification Loss", "classif", 0, 1, TRUE, aggregated = FALSE)
+#' @include measures.R
+add_measure(one_zero, "One-Zero Utility Function", "classif", 0, 1, FALSE, aggregated = FALSE)
