@@ -15,8 +15,8 @@
 #' @export
 sae = function(truth, response, ...) {
   assert_regr(truth, response = response)
-  sum(ae(truth, response))
+  sum(.ae(truth, response))
 }
 
 #' @include measures.R
-add_measure(sae, "Sum of Absolute Errors", "regr", 0, Inf, TRUE)
+add_measure(sae, "Sum of Absolute Errors", "regr", 0, Inf, TRUE, obs_loss = "ae")
