@@ -9,8 +9,13 @@ test_that("trigger all", {
       next
     }
     f = match.fun(m$id)
+
     perf = f(truth = truth, response = response)
-    expect_number(perf, na.ok = FALSE, lower = m$lower - tol, upper = m$upper + tol, label = m$id)
+    if (m$aggregated) {
+      expect_number(perf, na.ok = FALSE, lower = m$lower - tol, upper = m$upper + tol, label = m$id)
+    } else {
+      expect_numeric(perf, any.missing = FALSE, lower = m$lower - tol, upper = m$upper + tol, label = m$id)
+    }
 
     if ("sample_weights" %in% names(formals(f))) {
       sample_weights = runif(length(truth))
